pub struct CrossSigningKeyExport {
pub master_key: Option<String>,
pub self_signing_key: Option<String>,
pub user_signing_key: Option<String>,
}Expand description
A struct containing private cross signing keys that can be backed up or uploaded to the secret store.
Fields
master_key: Option<String>The seed of the master key encoded as unpadded base64.
self_signing_key: Option<String>The seed of the self signing key encoded as unpadded base64.
user_signing_key: Option<String>The seed of the user signing key encoded as unpadded base64.