pub struct RoomPendingKeyBundleDetails {
pub room_id: OwnedRoomId,
pub invite_accepted_at: MilliSecondsSinceUnixEpoch,
pub inviter: OwnedUserId,
}Expand description
A struct remembering details of a room that we recently joined following an invite (and so should accept a room key bundle if we receive one).
Fields
room_id: OwnedRoomIdThe ID of the room associated with this entry, used to track and enumerate all such rooms during the startup process. This enables the client to resume importing after a crash.
invite_accepted_at: MilliSecondsSinceUnixEpochA timestamp remembering when we observed the user accepting an invite using this client.
inviter: OwnedUserIdThe user ID of the person that invited us.