pub struct StoredRoomKeyBundleData {
pub sender_user: OwnedUserId,
pub sender_key: Curve25519PublicKey,
pub sender_data: SenderData,
pub bundle_data: RoomKeyBundleContent,
}Expand description
Information about an MSC4268 room key bundle.
Fields
sender_user: OwnedUserIdThe user that sent us this data.
sender_key: Curve25519PublicKeyThe Curve25519PublicKey of the device that sent us this data.
sender_data: SenderDataInformation about the sender of this data and how much we trust that information.
bundle_data: RoomKeyBundleContentThe room key bundle data itself.